package com.test.test.service.impl;

import java.util.List;
import com.test.common.utils.DateUtils;
import com.test.common.utils.SecurityUtils;
import com.test.test.domain.TestGroup;
import com.test.test.domain.UiElement;
import com.test.test.domain.qo.UiElementQO;
import com.test.test.mapper.TestGroupMapper;
import com.test.test.mapper.UiElementMapper;
import com.test.test.service.ITestGroupService;
import com.test.test.service.IUiElementService;
import jakarta.annotation.Resource;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * ui元素Service业务层处理
 * 
 * @author test
 * @date 2025-04-22
 */
@Service
public class UiElementServiceImpl implements IUiElementService
{
    @Resource
    private UiElementMapper uiElementMapper;
    @Resource
    private ITestGroupService testGroupService;

    /**
     * 查询ui元素
     * 
     * @param id ui元素主键
     * @return ui元素
     */
    @Override
    public UiElement selectUiElementById(Long id)
    {
        return uiElementMapper.selectUiElementById(id);
    }

    /**
     * 查询ui元素列表
     * 
     * @param uiElement ui元素
     * @return ui元素
     */
    @Override
    public List<UiElement> selectUiElementList(UiElement uiElement)
    {
        uiElement.setDelFlag("0");
        return uiElementMapper.selectUiElementList(uiElement);
    }

    @Override
    public List<UiElement> selectUiElementListNew(UiElementQO uiElement) {
        uiElement.setDelFlag("0");
        //这里要递归查询子元素
        Long groupId = uiElement.getGroupId();
        if (groupId != null){
            List<Long> allChildIds = testGroupService.getAllChildIds(groupId,"element");
            uiElement.setGroupIds(allChildIds);
        }
        // 查询元素列表
        List<UiElement> elements = uiElementMapper.selectUiElementListNew(uiElement);

        // 为每个元素设置groupNamePath
        for (UiElement element : elements) {
            String path = testGroupService.buildGroupPath(element.getGroupId());
            element.setGroupNamePath(path);
        }

        return elements;
    }

    /**
     * 新增ui元素
     * 
     * @param uiElement ui元素
     * @return 结果
     */
    @Override
    public int insertUiElement(UiElement uiElement)
    {
        uiElement.setDelFlag("0");
        uiElement.setCreateBy(SecurityUtils.getUsername());
        uiElement.setCreateTime(DateUtils.getNowDate());
        uiElement.setUpdateBy(SecurityUtils.getUsername());
        uiElement.setUpdateTime(DateUtils.getNowDate());
        return uiElementMapper.insertUiElement(uiElement);
    }

    /**
     * 修改ui元素
     * 
     * @param uiElement ui元素
     * @return 结果
     */
    @Override
    public int updateUiElement(UiElement uiElement)
    {
        uiElement.setUpdateBy(SecurityUtils.getUsername());
        uiElement.setUpdateTime(DateUtils.getNowDate());
        return uiElementMapper.updateUiElement(uiElement);
    }

    /**
     * 批量删除ui元素
     * 
     * @param ids 需要删除的ui元素主键
     * @return 结果
     */
    @Override
    public int deleteUiElementByIds(Long[] ids)
    {
        return uiElementMapper.deleteUiElementByIds(ids);
    }

    /**
     * 删除ui元素信息
     * 
     * @param id ui元素主键
     * @return 结果
     */
    @Override
    public int deleteUiElementById(Long id)
    {
        return uiElementMapper.deleteUiElementById(id);
    }
}
